<?php
// $Id: taxiselect.admin.inc,v 1.1.2.1.2.2 2009/09/07 14:51:36 aland Exp $

/**
 * @file
 * Administration related functions.
 */

/**
 * General settings form.
 */
function taxiselect_admin_settings() {
  $form['taxiselect_suggestions_limit'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect suggestion limit'),
    '#default_value' => variable_get('taxiselect_suggestions_limit', 3),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 20, 25)),
    '#description' => t('Shows a number of suggestions if the term matches multiple values or is not found on form submission. You must use the string [suggestions] in the forms error message strings for these to show.'),
    '#required' => TRUE,
  );
  $form['taxiselect_trigger_length'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect trigger length'),
    '#default_value' => variable_get('taxiselect_trigger_length', 3),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10)),
    '#description' => t('Minimum number of characters before returning an AJAX response. Useful to reduce server load.'),
    '#required' => TRUE,
  );
  $form['taxiselect_response_limit'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect response limit'),
    '#default_value' => variable_get('taxiselect_response_limit', 10),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 10, 15, 20, 25, 30, 40, 50, 75, 100, 150, 200, 250, 300, 400, 500)),
    '#description' => t('Maximum number of results to return per AJAX response. Useful to increase response times/reduce server load or to offer more choices to the user.'),
    '#required' => TRUE,
  );
  $form['taxiselect_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types to associate this widget with'),
    '#default_value' => array_filter(variable_get('taxiselect_node_types', array())),
    '#options' => array_map('check_plain', node_get_types('names')),
    '#description' => t('A list of node content types you want to use the taxiselect element with.'),
  );

  $vocabularies = array();
  $v = taxonomy_get_vocabularies();
  foreach ($v as $vocabulary) {
    $vocabularies[$vocabulary->vid] = check_plain($vocabulary->name);
  }
  $form['taxiselect_vocabularies'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Vocabularies to associate this widget with'),
    '#default_value' => array_filter(variable_get('taxiselect_vocabularies', array())),
    '#options' => $vocabularies,
    '#description' => t('A list of vocabularies you want to use the taxiselect element with. Free tagged vocabularies always use the standard core implementation.'),
  );

  $form['taxiselect_admin_vocabularies'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Vocabularies to associate this widget with on administrative term pages'),
    '#default_value' => array_filter(variable_get('taxiselect_admin_vocabularies', array())),
    '#options' => $vocabularies,
    '#description' => t('A list of vocabularies you want to use the taxiselect element with. Free tagged vocabularies always use the standard core implementation.'),
  );
  $tmp_vocab = new StdClass();
  $tmp_vocab->name = t('EXAMPLE VOCAB NAME');
  $tmp_vocab->vid = NULL;
  $tmp_value = t('EXAMPLE USER INPUT');
  $form['multiple_matches'] = array(
    '#type' => 'fieldset',
    '#title' => t('Multiple term matches found message'),
    '#description' => '<p>'. t('This allows you to override the custom error message for each vocabulary. The standard error message is:') .'</p>'
      .'<ul><li>'. theme('taxiselect_message_multiple_matches', $tmp_vocab, $tmp_value) .'</li><ul>',
  );

  $form['not_found'] = array(
    '#type' => 'fieldset',
    '#title' => t('Term not found message'),
    '#collapsible' => TRUE,
    '#description' => '<p>'. t('This allows you to override the custom error message for each vocabulary. The standard error message is:') .'</p>'
      .'<ul><li>'. theme('taxiselect_message_not_found', $tmp_vocab, $tmp_value) .'</li><ul>',
  );

  $form['free_tagging'] = array(
    '#type' => 'fieldset',
    '#title' => t('Psuedo free tagging'),
    '#collapsible' => TRUE,
    '#description' => '<p>'. t('Free tagging removes the hierarchical structure in vocabularies. This option provides a way to free tag new terms into the vocabulary without having to use the add term form. This option creates the term on add / submit, even if the page is not saved. If the "%hide" option is selected, the new term is appended to the first parental match.', array('%hide' => t('Hide top level categories.'))) .'</p>',
  );

  $form['skip_root'] = array(
    '#type' => 'fieldset',
    '#title' => t('Hide top level categories'),
    '#collapsible' => TRUE,
    '#description' => '<p>'. t('If enabled, the root level will be ignored. For example, say the top level is continents, such as Asia, and the second level is countries, this option will hide the continent terms. This restricts selection of the root terms. This option will be ignored on the admin pages.') .'</p>',
  );

  // custom error messages
  foreach ($v as $vocabulary) {
    $form['not_found']['taxiselect_message_not_found_'. $vocabulary->vid] = array(
      '#type' => 'textfield',
      '#title' => t('Custom message for %vocab', array('%vocab' => $vocabulary->name)),
      '#default_value' => variable_get('taxiselect_message_not_found_'. $vocabulary->vid, ''),
    );
    $form['multiple_matches']['taxiselect_message_multiple_matches_'. $vocabulary->vid] = array(
      '#type' => 'textfield',
      '#title' => t('Custom message for %vocab', array('%vocab' => $vocabulary->name)),
      '#default_value' => variable_get('taxiselect_message_multiple_matches_'. $vocabulary->vid, ''),
    );
    $form['free_tagging']['taxiselect_free_tagging_'. $vocabulary->vid] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable free tagging via taxiselect for %vocab', array('%vocab' => $vocabulary->name)),
      '#default_value' => variable_get('taxiselect_free_tagging_'. $vocabulary->vid, 0),
    );
    $form['skip_root']['taxiselect_skip_root_'. $vocabulary->vid] = array(
      '#type' => 'checkbox',
      '#title' => t('Hide top level categories for %vocab', array('%vocab' => $vocabulary->name)),
      '#default_value' => variable_get('taxiselect_skip_root_'. $vocabulary->vid, 0),
    );
  }
  return system_settings_form($form);
}


// The taxonomy term form.
function _taxiselect_form_taxonomy_form_term_alter(&$form, &$form_state) {
  // Don't alter the form when it's in confirmation mode.
  if (isset($form_state['confirm_delete']) || isset($form_state['confirm_parents'])) {
    return;
  }
  $vocabulary = (object) $form['#vocabulary'];
  $parent = array_keys(taxonomy_get_parents($form['tid']['#value']));
  $relations = array_keys(taxonomy_get_related($form['tid']['#value']));
  // A term can't be the child of itself, nor of its children.
  $children = taxonomy_get_tree($vocabulary->vid, $form['tid']['#value']);
  foreach ($children as $child) {
    $exclude[] = $child->tid;
  }
  $exclude[] = $form['tid']['#value'];

  $taxiselect_vocabularies = array_filter(variable_get('taxiselect_admin_vocabularies', array()));
  if (in_array($vocabulary->vid, $taxiselect_vocabularies)) {
    $form['advanced']['parent'] = array(
      '#title' => t('Parents'),
      '#type' => 'taxiselect_element',
      '#vocabulary' => $vocabulary,
      '#multiple' => 0,
      '#default_value' => $parent,
      '#exclude' => $exclude,
    );
    $form['advanced']['relations'] = array(
      '#title' => t('Related terms'),
      '#type' => 'taxiselect_element',
      '#vocabulary' => $vocabulary,
      '#multiple' => 0,
      '#default_value' => $relations,
      '#exclude' => array($form['tid']['#value']),
    );
  }
  else {
    $form['advanced']['parent'] = _taxonomy_term_select(t('Parents'), 'parent', $parent, $vocabulary->vid, t('Parent terms') .'.', 1, '<'. t('root') .'>', $exclude);
    $form['advanced']['relations'] = _taxonomy_term_select(t('Related terms'), 'relations', $relations, $vocabulary->vid, NULL, 1, '<'. t('none') .'>', array($form['tid']['#value']));
  }
}
